# vim: set ts=4 et sw=4:

# install status tools for HP Smart Array RAID controller
class raid::driver::hpsa (
        $enabled = true,
    ) {

    if $enabled == true {
        if $::lsbdistcodename == 'precise' {
            notify{"no hpssacli package available for Ubuntu Precise": }
            $packages = 'purged'
            $repo = false
        } else {
            $packages = 'present'
            $repo = true
        }
    } else {
        $packages = 'purged'
        $repo = false
    }

    class { 'apt::repo::hp':
        enabled => $repo,
    }

    package { 'hpssacli':
        ensure => $packages,
    }

    # The HP package includes an insane postinst that does "mv /opt/usr/sbin/*
    # /usr/sbin". Undo the postinst so .md5sums and other package metadata
    # correlates to what is installed.
    if $packages == 'present' {

        file { ['/opt/usr', '/opt/usr/sbin']:
            ensure  => 'directory',
            owner   => 'root',
            group   => 'root',
            mode    => '0555',
            require => Package['hpssacli'],
        }

        exec { '/bin/mv -f /usr/sbin/hpssacli /opt/usr/sbin/hpssacli':
            onlyif  => [
                '/usr/bin/test -f /usr/sbin/hpssacli',
                '/bin/grep opt/usr/sbin/hpssacli$ /var/lib/dpkg/info/hpssacli.md5sums',
            ],
            unless  => '/bin/grep " usr/sbin/hpssacli$" /var/lib/dpkg/info/hpssacli.md5sums',
            require => File['/opt/usr/sbin'],
        }

    }

}
